﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Infragistics.Win;
using System.Windows.Forms;

namespace BorderSideDemo
{
    /// <summary>
    /// Represents an Border Draw Filter for the Ultra Win Controls.
    /// </summary>
    public class UltraBorderSideDrawFilter : IUIElementDrawFilter
    {
        /// <summary>
        /// Represents the default extended Constructor.
        /// </summary>
        public UltraBorderSideDrawFilter()
        {
            this.sides = Border3DSide.All;
        }

        /// <summary>
        /// Represents an extended Constructor.
        /// </summary>
        /// <param name="sidesToDraw"></param>
        public UltraBorderSideDrawFilter(Border3DSide sidesToDraw)
        {
            this.sides = sidesToDraw;
        }

        /// <summary>
        /// Represents the Border Sides to Draw.
        /// </summary>
        private Border3DSide sides = Border3DSide.All;

        /// <summary>
        /// Represents the Border Sides to Draw.
        /// </summary>
        public Border3DSide Sides
        {
            get
            {
                return sides;
            }
            set
            {
                sides = value;
            }
        }

        /// <summary>
        /// <see cref="IUIElementDrawFilter.GetPhasesToFilter"/>
        /// </summary>
        /// <param name="drawParams"></param>
        /// <returns></returns>
        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if (drawParams.Element is ControlUIElementBase)
            {
                return DrawPhase.BeforeDrawBorders;
            }

            return Infragistics.Win.DrawPhase.None;
        }

        /// <summary>
        /// <see cref="IUIElementDrawFilter.DrawElement"/>
        /// </summary>
        /// <param name="drawPhase"></param>
        /// <param name="drawParams"></param>
        /// <returns></returns>
        public Boolean DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            switch (drawPhase)
            {
                case Infragistics.Win.DrawPhase.BeforeDrawBorders:
                    {
                        drawParams.DrawBorders(drawParams.Element.BorderStyle, sides);                        
                        return true;
                    }
            }

            return false;
        }
    }
}
